@@ -841,20 +841,15 @@ void TGTextEditor::InterruptMacro()
 
 void TGTextEditor::About()
 {
-#ifdef R__UNIX
-   TString rootx = TROOT::GetBinDir() + "/root -a &";
-   gSystem->Exec(rootx);
-#else
 #ifdef WIN32
    new TWin32SplashThread(kTRUE);
 #else
    char str[32];
-   sprintf(str, "About ROOT %s...", gROOT->GetVersion());
+   snprintf(str, 32, "About ROOT %s...", gROOT->GetVersion());
    TRootHelpDialog *hd = new TRootHelpDialog(this, str, 600, 400);
    hd->SetText(gHelpAbout);
    hd->Popup();
 #endif
-#endif
 }
 
 ////////////////////////////////////////////////////////////////////////////////
