@@ -64,6 +64,19 @@ fIntegral(0), fIntegralStatus(kNoInt)
    fAxes.SetOwner();
 }
 
+THnBase::THnBase(const char* name, const char* title, const std::vector<TAxis>& axes):
+  TNamed(name, title), fNdimensions(axes.size()), fAxes(axes.size()), fBrowsables(axes.size()),
+  fEntries(0), fTsumw(0), fTsumw2(-1.), fTsumwx(axes.size()), fTsumwx2(axes.size()),
+  fIntegral(0), fIntegralStatus(kNoInt)
+{
+  size_t i{};
+  for (auto& a: axes)
+    fAxes.AddAtAndExpand(a.Clone(), i++);
+  // Assuming SetTitle is done by TNamed.
+  fAxes.SetOwner();
+}
+
+
 THnBase::THnBase(const char *name, const char *title, Int_t dim, const Int_t *nbins,
                  const std::vector<std::vector<double>> &xbins)
    : TNamed(name, title), fNdimensions(dim), fAxes(dim), fBrowsables(dim), fEntries(0), fTsumw(0), fTsumw2(-1.),
@@ -530,7 +543,7 @@ TFitResultPtr THnBase::Fit(TF1 *f ,Option_t *option ,Option_t *goption)
 /// \param idx an array of bin index in each dimension.
 /// \return vector of bin centers in each dimension; empty in case of error.
 /// \note Throws error if size is different from nDimensions.
-/// \sa GetAxis(dim)::GetBinCenter(idx) as an alternative
+/// \note See also GetAxis(dim)::GetBinCenter(idx) as an alternative
 std::vector<Double_t> THnBase::GetBinCenter(const std::vector<Int_t> &idx) const
 {
    if (idx.size() != static_cast<decltype(idx.size())>(fNdimensions)) {
@@ -684,6 +697,9 @@ TObject* THnBase::ProjectionAny(Int_t ndim, const Int_t* dim,
    Bool_t haveErrors = GetCalculateErrors();
    Bool_t wantErrors = haveErrors || (option && (strchr(option, 'E') || strchr(option, 'e')));
 
+   if (wantNDim && wantErrors)
+      hn->Sumw2();
+
    Int_t* bins  = new Int_t[ndim];
    Long64_t myLinBin = 0;
 
@@ -1339,7 +1355,7 @@ void THnBase::ResetBase(Option_t * /*option = ""*/)
 /// \brief Compute integral (sum of counts) of histogram in all dimensions
 /// \param respectAxisRange if false, count all bins including under/overflows,
 ///                         if true, restrict sum to the user-set axis range
-/// \sa Projection(0)::Integral() as alternative
+/// \note See also Projection(0)::Integral() as alternative
 /// \note this function is different from ComputeIntegral, that is a normalized
 /// cumulative sum
 Double_t THnBase::Integral(Bool_t respectAxisRange) const
