@@ -1,6 +1,7 @@
 #include "ROOT/RDataFrame.hxx"
 #include "ROOT/TSeq.hxx"
 #include "ROOT/RTrivialDS.hxx"
+#include "Compression.h"
 #include "TH1F.h"
 #include "TRandom.h"
 #include "TSystem.h"
@@ -142,7 +143,8 @@ TEST(Cache, InternalColumnsSnapshot)
    auto colName = "tdfMySecretcol_";
    auto orig = tdf.Define(colName, [&f]() { return f++; }).Define("dummy", []() { return 0.f; });
    auto cached = orig.Cache<float, float>({colName, "dummy"});
-   auto snapshot = cached.Snapshot("t", "InternalColumnsSnapshot.root", "", {"RECREATE", ROOT::kZLIB, 0, 0, 99, false});
+   auto snapshot = cached.Snapshot("t", "InternalColumnsSnapshot.root", "",
+                                   {"RECREATE", ROOT::RCompressionSetting::EAlgorithm::kZLIB, 0, 0, 99, false});
 
    auto op = [&]() {
       testing::internal::CaptureStderr();
