@@ -28,11 +28,11 @@ ClassImp(TLeafO);
 
 TLeafO::TLeafO(): TLeaf()
 {
-   fValue   = 0;
-   fPointer = 0;
-   fMinimum = 0;
-   fMaximum = 0;
-   fLenType = sizeof(Bool_t);
+   fValue   = nullptr;
+   fPointer = nullptr;
+   fMinimum = false;
+   fMaximum = false;
+   fLenType = sizeof(bool);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -41,11 +41,11 @@ TLeafO::TLeafO(): TLeaf()
 TLeafO::TLeafO(TBranch *parent, const char *name, const char *type)
    : TLeaf(parent,name,type)
 {
-   fLenType = sizeof(Bool_t);
-   fMinimum = 0;
-   fMaximum = 0;
-   fValue   = 0;
-   fPointer = 0;
+   fLenType = sizeof(bool);
+   fMinimum = false;
+   fMaximum = false;
+   fValue   = nullptr;
+   fPointer = nullptr;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -53,7 +53,7 @@ TLeafO::TLeafO(TBranch *parent, const char *name, const char *type)
 
 TLeafO::~TLeafO()
 {
-   if (ResetAddress(0,kTRUE)) delete [] fValue;
+   if (ResetAddress(nullptr,true)) delete [] fValue;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -92,16 +92,16 @@ const char *TLeafO::GetTypeName() const
 ////////////////////////////////////////////////////////////////////////////////
 /// Copy/set fMinimum and fMaximum to include/be wide than those of the parameter
 
-Bool_t TLeafO::IncludeRange(TLeaf *input)
+bool TLeafO::IncludeRange(TLeaf *input)
 {
     if (input) {
         if (input->GetMaximum() > this->GetMaximum())
             this->SetMaximum( input->GetMaximum() );
         if (input->GetMinimum() < this->GetMinimum())
             this->SetMinimum( input->GetMinimum() );
-        return kTRUE;
+        return true;
     } else {
-        return kFALSE;
+        return false;
     }
 }
 
@@ -186,21 +186,21 @@ void TLeafO::SetAddress(void *add)
    }
    if (add) {
       if (TestBit(kIndirectAddress)) {
-         fPointer = (Bool_t**) add;
+         fPointer = (bool**) add;
          Int_t ncountmax = fLen;
          if (fLeafCount) ncountmax = fLen*(fLeafCount->GetMaximum() + 1);
          if ((fLeafCount && ncountmax > Int_t(fLeafCount->GetValue())) ||
-             ncountmax > fNdata || *fPointer == 0) {
+             ncountmax > fNdata || *fPointer == nullptr) {
             if (*fPointer) delete [] *fPointer;
             if (ncountmax > fNdata) fNdata = ncountmax;
-            *fPointer = new Bool_t[fNdata];
+            *fPointer = new bool[fNdata];
          }
          fValue = *fPointer;
       } else {
-         fValue = (Bool_t*)add;
+         fValue = (bool*)add;
       }
    } else {
-      fValue = new Bool_t[fNdata];
-      fValue[0] = 0;
+      fValue = new bool[fNdata];
+      fValue[0] = false;
    }
 }
